searchNodes=[{"doc":"Implements Unicode regular expressions by transforming them into regular expressions supported by the Elixir Regex module.","ref":"Unicode.Regex.html","title":"Unicode.Regex","type":"module"},{"doc":"Compiles a binary regular expression after expanding any Unicode Sets.Argumentsstring is a regular expression in string formoptions is a string or a list which is passed unchanged to Regex.compile/2. The default is &quot;u&quot; meaning the regular expression will operate in Unicode modeReturns{:ok, regex} or{:error, {message, index}}NotesThis function operates by splitting the string at the boundaries of Unicode Set markers which are:Posix style: [: and :]Perl style: \\p{ and }This parsing is naive meaning that is does not take any character escaping into account when s plitting the string.Exampleiex&gt; Unicode.Regex.compile(&quot;[:Zs:]&quot;) {:ok, ~r/[\\x{20}\\x{A0}\\x{1680}\\x{2000}-\\x{200A}\\x{202F}\\x{205F}\\x{3000}]/u} iex&gt; Unicode.Regex.compile(&quot;\\\\p{Zs}&quot;) {:ok, ~r/[\\x{20}\\x{A0}\\x{1680}\\x{2000}-\\x{200A}\\x{202F}\\x{205F}\\x{3000}]/u} iex&gt; Unicode.Regex.compile(&quot;[:ZZZZ:]&quot;) {:error, {&#39;POSIX named classes are supported only within a class&#39;, 0}}","ref":"Unicode.Regex.html#compile/2","title":"Unicode.Regex.compile/2","type":"function"},{"doc":"Compiles a binary regular expression after interpolating any Unicode Sets.Argumentsstring is a regular expression in string form.options is a string or a list which is passed unchanged to Regex.compile/2. The default is &quot;u&quot; meaning the regular expression will operate in Unicode modeReturnsregex orraises an exceptionExampleiex&gt; Unicode.Regex.compile!(&quot;[:Zs:]&quot;) ~r/[\\x{20}\\x{A0}\\x{1680}\\x{2000}-\\x{200A}\\x{202F}\\x{205F}\\x{3000}]/u","ref":"Unicode.Regex.html#compile!/2","title":"Unicode.Regex.compile!/2","type":"function"},{"doc":"","ref":"Unicode.Regex.html#is_perl_set/1","title":"Unicode.Regex.is_perl_set/1","type":"macro"},{"doc":"Returns a boolean indicating whether there was a match or not with a Unicode Set.Argumentsregex_string is a regular expression in string form.string is any string against which the regex match is executedoptions is a string or a list which is passed unchanged to Regex.compile/2. The default is &quot;u&quot; meaning the regular expression will operate in Unicode modeReturnsa boolean indicating if there was a match orraises an exception if regex is not a valid regular expression.Exampleiex&gt; Unicode.Regex.match?(&quot;[:Sc:]&quot;, &quot;$&quot;) true","ref":"Unicode.Regex.html#match?/3","title":"Unicode.Regex.match?/3","type":"function"},{"doc":"Split a regex into character classes so that these can then be later compiled.Argumentsstring is a regular expression in string form.ReturnsA list of string split at the boundaries of unicode setsExampleiex&gt; Unicode.Regex.split_character_classes(&quot;This is [:Zs:] and more&quot;) [&quot;This is &quot;, &quot;[:Zs:]&quot;, &quot; and more&quot;]","ref":"Unicode.Regex.html#split_character_classes/1","title":"Unicode.Regex.split_character_classes/1","type":"function"},{"doc":"","ref":"Unicode.Regex.Match.html","title":"Unicode.Regex.Match","type":"module"},{"doc":"UsageFunction guardsThis is helpful in defining function guards. For example:defmodule Guards do require Unicode.Set # Define a guard that checks if a codepoint is a unicode digit defguard digit?(x) when Unicode.Set.match?(x, &quot;[[:Nd:]]&quot;) end defmodule MyModule do require Guards # Define a function using the previously defined guard def my_function(&lt;&lt; x :: utf8, _rest :: binary&gt;&gt;) when Guards.digit?(x) do IO.puts &quot;Its a digit!&quot; end # Define a guard directly on the function def my_other_function_(&lt;&lt; x :: utf8, _rest :: binary&gt;&gt;) when Unicode.Set.match?(x, &quot;[[:Nd:]]&quot;) do IO.puts &quot;Its also a digit!&quot; end endGenerating compiled patterns for String matchingString.split/3 and String.replace/3 allow for patterns and compiled patterns to be used with compiled patterns being the more performant approach. Unicode Set supports the generation of patterns and compiled patterns:iex&gt; pattern = Unicode.Set.compile_pattern &quot;[[:digit:]]&quot; iex&gt; list = String.split(&quot;abc1def2ghi3jkl&quot;, pattern) [&quot;abc&quot;, &quot;def&quot;, &quot;ghi&quot;, &quot;jkl&quot;]Generating NimbleParsec rangesThe parser generator nimble_parsec allows a list of codepoint ranges as parameters to several combinators. Unicode Set can generate such ranges:iex&gt; Unicode.Set.utf8_char(&quot;[[^abcd][mnb]]&quot;) [{:not, 97}, {:not, 98}, {:not, 99}, {:not, 100}, 98, 109, 110]This can be used as shown in the following example:defmodule MyCombinators do import NimbleParsec @digit_list = Unicode.Set.to_utf8_char(&quot;[[:digit:]]&quot;) def unicode_digit do utf8_char(@digit_list) |&gt; label(&quot;a digit in any Unicode script&quot;) end endCompiling extended regular expressionsThe Regex module supports a limited set of Unicode Sets. The Unicode.Regex module provides compile/2 and compile!/2 functions that have the same arguments and compatible functionality with Regexp.compile/2 other that they pre-process the regular expression, expanding any Unicode Sets. This makes it simple to incorporate Unicode Sets in regular expressions.All Unicode Sets are expanded, even those that are known to Regex.compile/2 since the erlang :re module upon Regex is based does not always keep pace with Unicode releases.For example:iex&gt; Unicode.Regex.compile(&quot;\\\\p{Zs}&quot;) {:ok, ~r/[\\x{20}\\x{A0}\\x{1680}\\x{2000}-\\x{200A}\\x{202F}\\x{205F}\\x{3000}]/u} iex&gt; Unicode.Regex.compile(&quot;[:graphic:]&quot;) {:ok, ~r/[\\x{20}-\\x{7E}\\x{A0}-\\x{AC}\\x{AE}-\\x{377}\\x{37A}-\\x{37F}...]/u}Other ExamplesThese examples show how to combine sets (union, difference and intersection) to deliver a flexible targeting of the required match.# The character &quot;๓&quot; is the thai digit `1` iex&gt; Unicode.Set.match? ?๓, &quot;[[:digit:]]&quot; true # Set operations allow union, insersection and difference # This example matches on digits, but not the Thai script iex&gt; Unicode.Set.match? ?๓, &quot;[[:digit:]-[:thai:]]&quot; falseCompile time parsingAs much work as possible is done at compile time in order to deliver good performance. The macro Unicode.Set.match?/2 parses the unicode set, expands the require codepoints and generates guard clauses at compile time. The resulting code is a simple set of boolean operators that executes quickly at runtime.Supported Unicode propertiesThis version of Unicode Set supports the following enumerable unicode properties in unicode sets:script such as [:script=arabic:], \\p{script=arabic} or [:arabic:]block such as [:block=sudanese:], \\p{block=sudanese} or [:sudanese:]general category such as [:Lu:], \\p{Lu}, [:gc=Lu:] or [:general category=Lu:]combining class such as [:ccc=230:]In addition, the following boolean properties are supported. These are expressed as [:white space:] or \\p{White Space}.PropertyPropertyPropertyPropertyalphabeticascii_hex_digitbidi_controlcasedchanges_when_casemappedchanges_when_lowercasedchanges_when_titlecasedchanges_when_uppercaseddashdefault_ignorable_code_pointdeprecateddiacriticextendergrapheme_basegrapheme_extendgrapheme_linkhex_digithyphenid_continueid_startideographicids_binary_operatorids_trinary_operatorjoin_controllogical_order_exceptionlowercasemathnoncharacter_code_pointother_alphabeticother_default_ignorable_code_pointother_grapheme_extendother_id_continueother_id_startother_lowercaseother_mathother_uppercasepattern_syntaxpattern_white_spaceprepended_concatenation_markquotation_markradicalregional_indicatorsentence_terminalsoft_dottedterminal_punctuationunified_ideographuppercasevariation_selectorwhite_spacexid_continuexid_startchanges_when_casefoldedIn all cases, property names and property values may include whitespace and mixed case notation.General CategoriesAbbreviationLong FormLLetterLuUppercase LetterLlLowercase LetterLtTitlecase LetterLmModifier LetterLoOther LetterMMarkMnNon-Spacing MarkMcSpacing Combining MarkMeEnclosing MarkNNumberNdDecimal Digit NumberNlLetter NumberNoOther NumberSSymbolSmMath SymbolScCurrency SymbolSkModifier SymbolSoOther SymbolPPunctuationPcConnector PunctuationPdDash PunctuationPsOpen PunctuationPeClose PunctuationPiInitial PunctuationPfFinal PunctuationPoOther PunctuationZSeparatorZsSpace SeparatorZlLine SeparatorZpParagraph SeparatorCOtherCcControlCfFormatCsSurrogateCoPrivate UseCnUnassignedDerived CategoriesLong FormAnyAny all code points [\\u{0}-\\u{10FFFF}]AssignedAssigned all assigned characters meaning \\P{Cn}ASCIIASCII all ASCII characters [\\u{0}-\\u{7F}]Compatibility Property NamesPropertyUnicode CategoryCommentsalpha\\p{Alphabetic}Alphabetic includes more than gc = Letter. Note that combining marks (Me, Mn, Mc) are required for words of many languages. While they could be applied to non-alphabetics, their principal use is on alphabetics. Alphabetic should not be used as an approximation for word boundaries: see word below.lower\\p{Lowercase}Lowercase includes more than gc = Lowercase_Letter (Ll).upper\\p{Uppercase}Uppercase includes more than gc = Uppercase_Letter (Lu).punct\\p{gc=Punctuation} \\p{gc=Symbol} - \\p{alpha}Punctuation and symbols.digit\\p{gc=Decimal_Number}[0..9] Non-decimal numbers (like Roman numerals) are normally excluded.xdigit\\p{gc=Decimal_Number} \\p{Hex_Digit}[0-9 A-F a-f] Hex_Digit contains 0-9 A-F, fullwidth and halfwidth, upper and lowercase.alnum\\p{alpha} \\p{digit}Simple combination of other propertiesspace\\p{Whitespace}blank\\p{gc=Space_Separator} \\N{CHARACTER TABULATION}&quot;horizontal&quot; whitespace: space separators plus U+0009 tab.cntrl\\p{gc=Control}The characters in \\p{gc=Format} share some, but not all aspects of control characters. Many format characters are required in the representation of plain text.graph[^\\p{space} \\p{gc=Control} \\p{gc=Surrogate} \\p{gc=Unassigned}]Warning: the set shown here is defined by excluding space, controls, and so on with ^.print\\p{graph} \\p{blank} -- \\p{cntrl}Includes graph and space-like characters.word\\p{alpha} \\p{gc=Mark} \\p{digit} \\p{gc=Connector_Punctuation} \\p{Join_Control}This is only an approximation to Word Boundaries. The Connector Punctuation is added in for programming language identifiers, thus adding _ and similar characters.Additional Derived propertiesIn addition to the Unicode properties, some additional properties are also defined for convenience. These properties related to quote marks and are:quote_markquote_mark_leftquote_mark_rightquote_mark_ambidextrousquote_mark_singlequote_mark_doubleAs above these properties can be expressed in mixed case with spaces and underscores inserted for readability. They can be used in the same way as any Unicode property name.Example Unicode SetsHere are a few examples of sets. Although elements of the syntax appear similar to regular expressions, unicode sets only expresses one or more ranges of unicode codepoints.PatternDescription[a-z]The lower case letters a through z[abc123]The six characters a,b,c,1,2 and 3[\\p{Letter}]All characters with the Unicode General Category of LetterString ValuesIn addition to being a set of characters (of Unicode code points), a UnicodeSet may also contain string values. Conceptually, the UnicodeSet is always a set of strings, not a set of characters, although in many common use cases the strings are all of length one, which reduces to being a set of characters.This concept can be confusing when first encountered, probably because similar set constructs from other environments (regular expressions) can only contain characters.Unicode Set PatternsPatterns are a series of characters bounded by square brackets that contain lists of characters and Unicode property sets. Lists are a sequence of characters that may have ranges indicated by a '-' between two characters, as in &quot;a-z&quot;. The sequence specifies the range of all characters from the left to the right, in Unicode order. For example, [a c d-f m] is equivalent to [a c d e f m]. Whitespace can be freely used for clarity as [a c d-f m] means the same as [acd-fm].Unicode property sets are specified by a Unicode property, such as [:Letter:]. For a list of supported properties, see the Properties section. For details on the use of short vs. long property and property value names, see the end of this section. The syntax for specifying the property names is an extension of either POSIX or Perl syntax with the addition of =value. For example, you can match letters by using the POSIX syntax [:Letter:], or by using the Perl-style syntax \\p{Letter}. The type can be omitted for the Category and Script properties, but is required for other properties.The table below shows the two kinds of syntax: POSIX and Perl style. Also, the table shows the &quot;Negative&quot;, which is a property that excludes all characters of a given kind. For example, [:^Letter:] matches all characters that are not [:Letter:].StylePositiveNegativePOSIX-style Syntax[:type=value:][:^type=value:]Perl-style Syntax\\p{type=value}\\P{type=value}These following low-level lists or properties then can be freely combined with the normal set operations (union, inverse, difference, and intersection):ExampleMeaningA B [[:letter:] [:number:]]To union two sets A and B, simply concatenate themA &amp; B [[:letter:] &amp; [a-z]]To intersect two sets A and B, use the '&amp;' operator.A - B [[:letter:] - [a-z]]To take the set-difference of two sets A and B, use the '-' operator.[^A] [^a-z]To invert a set A, place a ^ immediately after the opening [. Note that the complement only affects code points, not string values. In any other location, the ^ does not have a special meaning.PrecedenceThe binary operators of union, intersection, and set-difference have equal precedence and bind left-to-right. Thus the following are equivalent:[[:letter:] - [a-z] [:number:] &amp; [\\u0100-\\u01FF]][[[[[:letter:] - [a-z]] [:number:]] &amp; [\\u0100-\\u01FF]]Another example is that the set [[ace][bdf] - [abc][def]] is not the empty set, but instead the set [def]. That is because the syntax corresponds to the following UnicodeSet operations:start with [ace]union [bdf] -- we now have [abcdef]subtract [abc] -- we now have [def]union [def] -- no effect, we still have [def]This only really matters where there are the difference and intersection operations, as the union operation is commutative. To make sure that the - is the main operator, add brackets to group the operations as desired, such as [[ace][bdf] - [[abc][def]]].Another caveat with the &amp; and - operators is that they operate between sets. That is, they must be immediately preceded and immediately followed by a set. For example, the pattern [[:Lu:]-A] is illegal, since it is interpreted as the set [:Lu:] followed by the incomplete range -A. To specify the set of uppercase letters except for A, enclose the A in a set: [[:Lu:]-[A]].Examples[a] The set containing 'a'[a-z] The set containing 'a' through 'z' and all letters in between, in Unicode order[^a-z] The set containing all characters but 'a' through 'z', that is, U+0000 through 'a'-1 and 'z'+1 through U+FFFF[[pat1][pat2]] The union of sets specified by pat1 and pat2[[pat1]&amp;[pat2]] The intersection of sets specified by pat1 and pat2[[pat1]-[pat2]] The asymmetric difference of sets specified by pat1 and pat2[:Lu:] The set of characters belonging to the given Unicode category; in this case, Unicode uppercase letters. The long form for this is [:UppercaseLetter:].[:L:] The set of characters belonging to all Unicode categories starting with 'L', that is, [[:Lu:][:Ll:][:Lt:][:Lm:][:Lo:]]. The long form for this is [:Letter:].String Values in SetsString values are enclosed in {curly brackets}.Set expressionDescription[abc{def}]A set containing four members, the single characters a, b and c, and the string “def”[{abc}{def}]A set containing two members, the string “abc” and the string “def”.[{a}{b}{c}][abc]These two sets are equivalent. Each contains three items, the three individual characters a, b and c. A {string} containing a single character is equivalent to that same character specified in any other way.Character Quoting and Escaping in Unicode Set PatternsSingle QuoteTwo single quotes represents a single quote, either inside or outside single quotes.Text within single quotes is not interpreted in any way (except for two adjacent single quotes). It is taken as literal text (special characters become non-special).These quoting conventions for ICU UnicodeSets differ from those of regular expression character set expressions. In regular expressions, single quotes have no special meaning and are treated like any other literal character.Backslash EscapesOutside of single quotes, certain backslashed characters have special meaning. Note that these are escapes processed by Unicode Set (this library) and therefore require \\\\\\\\ to be entered as a prefix. Elixir also provides similar escapes as native part of its string processing and Elixir's escapes are to be preferred where possible.EscapeDescription\\uhhhhExactly 4 hex digits; h in [0-9A-Fa-f]\\UhhhhhhhhExactly 8 hex digits\\xhh1-2 hex digitsCertain other escapes are native to Elixir and are applicable in Unicode Sets they are in any Elixir string:EscapeDescription\\aU+0007 (BELL)\\bU+0008 (BACKSPACE)\\tU+0009 (HORIZONTAL TAB)\\nU+000A (LINE FEED)\\vU+000B (VERTICAL TAB)\\fU+000C (FORM FEED)\\rU+000D (CARRIAGE RETURN)\\U+005C (BACKSLASH)\\xDDrepresents a single byte in hexadecimal (such as \\x13)\\uDDDD and \\u{D...}represents a Unicode codepoint in hexadecimal (such as \\u{1F600})Anything else following a backslash is mapped to itself, except in an environment where it is defined to have some special meaning. For example, \\p{Lu} is the set of uppercase letters in a Unicode Set.Any character formed as the result of a backslash escape loses any special meaning and is treated as a literal. In particular, note that \\u and \\U escapes create literal characters.WhitespaceWhitespace (as defined by the specification) is ignored unless it is quoted or backslashed.Property ValuesThe following property value variants are recognized:FormatExampleDescriptionshortLuomits the type (used to prevent ambiguity and only allowed with the Category and Script properties)mediumgc=Luuses an abbreviated type and valuelongGeneral_Category=Uppercase_Letteruses a full type and valueIf the type or value is omitted, then the equals sign is also omitted. The short style is only used for Category and Script properties because these properties are very common and their omission is unambiguous.In actual practice, you can mix type names and values that are omitted, abbreviated, or full. For example, if Category=Unassigned you could use what is in the table explicitly, \\p{gc=Unassigned}, \\p{Category=Cn}, or \\p{Unassigned}.When these are processed, case and whitespace are ignored so you may use them for clarity, if desired. For example, \\p{Category = Uppercase Letter} or \\p{Category = uppercase letter}.","ref":"Unicode.Set.html","title":"Unicode.Set","type":"module"},{"doc":"","ref":"Unicode.Set.html#compile_pattern/1","title":"Unicode.Set.compile_pattern/1","type":"function"},{"doc":"Returns a boolean based upon whether var matches the provided unicode_set.Argumentsvar is any integer variable (since codepoints are integers)unicode_set is a binary representation of a unicode set. An exception will be raised if unicode_set is not a compile time binaryReturnstrue or falseExamplesUnicode.Set.match?/2 can be used in as defguard argument. For example: defguard is_lower(codepoint) when Unicode.Set.match?(codepoint, &quot;[[:Lu:]]&quot;)Or as a guard clause itself: def my_function(&lt;&lt; codepoint :: utf8, _rest :: binary&gt;&gt;) #=&gt; when Unicode.Set.match?(codepoint, &quot;[[:Lu:]]&quot;)","ref":"Unicode.Set.html#match?/2","title":"Unicode.Set.match?/2","type":"macro"},{"doc":"","ref":"Unicode.Set.html#parse/1","title":"Unicode.Set.parse/1","type":"function"},{"doc":"","ref":"Unicode.Set.html#parse!/1","title":"Unicode.Set.parse!/1","type":"function"},{"doc":"Parses a unicode set and expands the set expressions then compacts the character ranges.","ref":"Unicode.Set.html#parse_and_reduce/1","title":"Unicode.Set.parse_and_reduce/1","type":"function"},{"doc":"","ref":"Unicode.Set.html#parse_and_reduce!/1","title":"Unicode.Set.parse_and_reduce!/1","type":"function"},{"doc":"","ref":"Unicode.Set.html#to_pattern/1","title":"Unicode.Set.to_pattern/1","type":"function"},{"doc":"","ref":"Unicode.Set.html#to_pattern!/1","title":"Unicode.Set.to_pattern!/1","type":"function"},{"doc":"","ref":"Unicode.Set.html#to_regex_string/1","title":"Unicode.Set.to_regex_string/1","type":"function"},{"doc":"","ref":"Unicode.Set.html#to_regex_string!/1","title":"Unicode.Set.to_regex_string!/1","type":"function"},{"doc":"","ref":"Unicode.Set.html#to_utf8_char/1","title":"Unicode.Set.to_utf8_char/1","type":"function"},{"doc":"","ref":"Unicode.Set.html#to_utf8_char!/1","title":"Unicode.Set.to_utf8_char!/1","type":"function"},{"doc":"","ref":"Unicode.Set.html#t:character_range/0","title":"Unicode.Set.character_range/0","type":"type"},{"doc":"","ref":"Unicode.Set.html#t:codepoint/0","title":"Unicode.Set.codepoint/0","type":"type"},{"doc":"","ref":"Unicode.Set.html#t:codepoint_range/0","title":"Unicode.Set.codepoint_range/0","type":"type"},{"doc":"","ref":"Unicode.Set.html#t:nimble_list/0","title":"Unicode.Set.nimble_list/0","type":"type"},{"doc":"","ref":"Unicode.Set.html#t:nimble_range/0","title":"Unicode.Set.nimble_range/0","type":"type"},{"doc":"","ref":"Unicode.Set.html#t:operation/0","title":"Unicode.Set.operation/0","type":"type"},{"doc":"","ref":"Unicode.Set.html#t:operator/0","title":"Unicode.Set.operator/0","type":"type"},{"doc":"","ref":"Unicode.Set.html#t:range/0","title":"Unicode.Set.range/0","type":"type"},{"doc":"","ref":"Unicode.Set.html#t:range_list/0","title":"Unicode.Set.range_list/0","type":"type"},{"doc":"","ref":"Unicode.Set.html#t:state/0","title":"Unicode.Set.state/0","type":"type"},{"doc":"","ref":"Unicode.Set.html#t:string_range/0","title":"Unicode.Set.string_range/0","type":"type"},{"doc":"","ref":"Unicode.Set.html#t:t/0","title":"Unicode.Set.t/0","type":"type"},{"doc":"Functions to operate on Unicode sets:IntersectionDifferenceUnionInversion","ref":"Unicode.Set.Operation.html","title":"Unicode.Set.Operation","type":"module"},{"doc":"Combines all the ranges into a single listThis function is called iff the Unicode Sets are formed by unions only. If the set operations of intersection or difference are present then the ranges will need to be expanded via expand/1.","ref":"Unicode.Set.Operation.html#combine/1","title":"Unicode.Set.Operation.combine/1","type":"function"},{"doc":"Compact overlapping and adjacent ranges","ref":"Unicode.Set.Operation.html#compact_ranges/1","title":"Unicode.Set.Operation.compact_ranges/1","type":"function"},{"doc":"Returns the complement (inverse) of a set.","ref":"Unicode.Set.Operation.html#complement/1","title":"Unicode.Set.Operation.complement/1","type":"function"},{"doc":"Removes one list of 2-tuples representing Unicode codepoints from another.Returns the first list of codepoint ranges minus the codepoints in the second list.","ref":"Unicode.Set.Operation.html#difference/2","title":"Unicode.Set.Operation.difference/2","type":"function"},{"doc":"Expand takes a reduced AST and expands it into a single list of codepoint tuples.","ref":"Unicode.Set.Operation.html#expand/1","title":"Unicode.Set.Operation.expand/1","type":"function"},{"doc":"","ref":"Unicode.Set.Operation.html#expand_string_range/1","title":"Unicode.Set.Operation.expand_string_range/1","type":"function"},{"doc":"Expand string ranges like {ab}-{cd}","ref":"Unicode.Set.Operation.html#expand_string_ranges/1","title":"Unicode.Set.Operation.expand_string_ranges/1","type":"function"},{"doc":"Returns a boolean indicating whether the given AST includes set operations intersection or difference.When these operations exist then all ranges - including ^ ranges needs to be expanded. If there are no intersections or differences then the ^ ranges can be directly translated to guard clauses or a list of elixir ranges.","ref":"Unicode.Set.Operation.html#has_difference_or_intersection?/1","title":"Unicode.Set.Operation.has_difference_or_intersection?/1","type":"function"},{"doc":"Returns the intersection of two lists of 2-tuples representing codepoint ranges.The result is a single list of codepoint ranges that represents the common codepoints in the two lists.","ref":"Unicode.Set.Operation.html#intersect/2","title":"Unicode.Set.Operation.intersect/2","type":"function"},{"doc":"Reduces all sets, properties and ranges to a list of 2-tuples expressing a range of codepoints.It can return one of two forms[{:in, [tuple_list]}] for an inclusion list[{:not_in, [tuple_list]}] for an exclusion listor a combination of both.Attempts are made to preserve :not_in clauses as long as possible since many uses, like regexes and nimble_parsec can consume :not_in style ranges.When only single character classes are presented, or several classes which are unions, :not_in can be preserved.When intersections and differences are required, the rnages must be both reduced and expanded in order for this set operations to complete.","ref":"Unicode.Set.Operation.html#reduce/1","title":"Unicode.Set.Operation.reduce/1","type":"function"},{"doc":"Returns the difference of two lists of 2-tuples representing codepoint ranges.The result is a single list of codepoint ranges that represents the codepoints that are in either of the two lists but not both.","ref":"Unicode.Set.Operation.html#symmetric_difference/2","title":"Unicode.Set.Operation.symmetric_difference/2","type":"function"},{"doc":"Prewalks the expanded AST from a parsed Unicode Set invoking a function on each codepoint range in the set.","ref":"Unicode.Set.Operation.html#traverse/2","title":"Unicode.Set.Operation.traverse/2","type":"function"},{"doc":"","ref":"Unicode.Set.Operation.html#traverse/3","title":"Unicode.Set.Operation.traverse/3","type":"function"},{"doc":"Merges two lists of 2-tuples representing ranges of codepoints. The result is a single list of 2-tuple codepoint ranges that includes all codepoint from the two lists.It is assumed that both lists are sorted prior to merging.","ref":"Unicode.Set.Operation.html#union/2","title":"Unicode.Set.Operation.union/2","type":"function"},{"doc":"","ref":"Unicode.Set.Search.html","title":"Unicode.Set.Search","type":"module"},{"doc":"","ref":"Unicode.Set.Search.html#build_search_tree/1","title":"Unicode.Set.Search.build_search_tree/1","type":"function"},{"doc":"","ref":"Unicode.Set.Search.html#extract_and_expand_string_ranges/1","title":"Unicode.Set.Search.extract_and_expand_string_ranges/1","type":"function"},{"doc":"","ref":"Unicode.Set.Search.html#member?/2","title":"Unicode.Set.Search.member?/2","type":"function"},{"doc":"","ref":"Unicode.Set.Search.html#string_member?/2","title":"Unicode.Set.Search.string_member?/2","type":"function"},{"doc":"Exception raised when an a Unicode Set cannot be parsed","ref":"Unicode.Set.ParseError.html","title":"Unicode.Set.ParseError","type":"exception"},{"doc":"Unicode Set A Unicode Set is a representation of a set of Unicode characters or character strings. The contents of that set are specified by patterns or by building them programmatically. This library implements parsing of unicode sets, resolving them to a list of codepoints and matching a given codepoint to that list. This expansion supports the following public API:Unicode.Set.match?/2 which is a macro that matches a codepoint to a unicode set.Unicode.Regex.compile/2 which pre-processes a regex string expanding unicode sets into a regex executable by the Regex module.Unicode.Set.to_utf8_char/1 that converts a unicode set into a form usable with nimble_parsecUnicode.Set.compile_pattern/1 which converts a unicode set into a string that is then compiled with :binary.compile_pattern/1.The implementation conforms closely to the Unicode Set specification but currently omits support for the \\N{codepoint_name} syntax.","ref":"readme.html","title":"Unicode Set","type":"extras"},{"doc":"Function guardsThis is helpful in defining function guards. For example:defmodule Guards do require Unicode.Set # Define a guard that checks if a codepoint is a unicode digit defguard digit?(x) when Unicode.Set.match?(x, &quot;[[:Nd:]]&quot;) end defmodule MyModule do require Guards # Define a function using the previously defined guard def my_function(&lt;&lt; x :: utf8, _rest :: binary&gt;&gt;) when Guards.digit?(x) do IO.puts &quot;Its a digit!&quot; end # Define a guard directly on the function def my_other_function_(&lt;&lt; x :: utf8, _rest :: binary&gt;&gt;) when Unicode.Set.match?(x, &quot;[[:Nd:]]&quot;) do IO.puts &quot;Its also a digit!&quot; end endGenerating compiled patterns for String matchingString.split/3 and String.replace/3 allow for patterns and compiled patterns to be used with compiled patterns being the more performant approach. Unicode Set supports the generation of patterns and compiled patterns:iex&gt; pattern = Unicode.Set.compile_pattern &quot;[[:digit:]]&quot; iex&gt; list = String.split(&quot;abc1def2ghi3jkl&quot;, pattern) [&quot;abc&quot;, &quot;def&quot;, &quot;ghi&quot;, &quot;jkl&quot;]Generating NimbleParsec rangesThe parser generator nimble_parsec allows a list of codepoint ranges as parameters to several combinators. Unicode Set can generate such ranges:iex&gt; Unicode.Set.utf8_char(&quot;[[^abcd][mnb]]&quot;) [{:not, 97}, {:not, 98}, {:not, 99}, {:not, 100}, 98, 109, 110]This can be used as shown in the following example:defmodule MyCombinators do import NimbleParsec @digit_list = Unicode.Set.to_utf8_char(&quot;[[:digit:]]&quot;) def unicode_digit do utf8_char(@digit_list) |&gt; label(&quot;a digit in any Unicode script&quot;) end endCompiling extended regular expressionsThe Regex module supports a limited set of Unicode Sets. The Unicode.Regex module provides compile/2 and compile!/2 functions that have the same arguments and compatible functionality with Regexp.compile/2 other that they pre-process the regular expression, expanding any Unicode Sets. This makes it simple to incorporate Unicode Sets in regular expressions.All Unicode Sets are expanded, even those that are known to Regex.compile/2 since the erlang :re module upon Regex is based does not always keep pace with Unicode releases.For example:iex&gt; Unicode.Regex.compile(&quot;\\\\p{Zs}&quot;) {:ok, ~r/[\\x{20}\\x{A0}\\x{1680}\\x{2000}-\\x{200A}\\x{202F}\\x{205F}\\x{3000}]/u} iex&gt; Unicode.Regex.compile(&quot;[:graphic:]&quot;) {:ok, ~r/[\\x{20}-\\x{7E}\\x{A0}-\\x{AC}\\x{AE}-\\x{377}\\x{37A}-\\x{37F}...]/u}Other ExamplesThese examples show how to combine sets (union, difference and intersection) to deliver a flexible targeting of the required match.# The character &quot;๓&quot; is the thai digit `1` iex&gt; Unicode.Set.match? ?๓, &quot;[[:digit:]]&quot; true # Set operations allow union, insersection and difference # This example matches on digits, but not the Thai script iex&gt; Unicode.Set.match? ?๓, &quot;[[:digit:]-[:thai:]]&quot; falseCompile time parsingAs much work as possible is done at compile time in order to deliver good performance. The macro Unicode.Set.match?/2 parses the unicode set, expands the require codepoints and generates guard clauses at compile time. The resulting code is a simple set of boolean operators that executes quickly at runtime.","ref":"readme.html#usage","title":"Unicode Set - Usage","type":"extras"},{"doc":"This version of Unicode Set supports the following enumerable unicode properties in unicode sets:script such as [:script=arabic:], \\p{script=arabic} or [:arabic:]block such as [:block=sudanese:], \\p{block=sudanese} or [:sudanese:]general category such as [:Lu:], \\p{Lu}, [:gc=Lu:] or [:general category=Lu:]combining class such as [:ccc=230:]In addition, the following boolean properties are supported. These are expressed as [:white space:] or \\p{White Space}.PropertyPropertyPropertyPropertyalphabeticascii_hex_digitbidi_controlcasedchanges_when_casemappedchanges_when_lowercasedchanges_when_titlecasedchanges_when_uppercaseddashdefault_ignorable_code_pointdeprecateddiacriticextendergrapheme_basegrapheme_extendgrapheme_linkhex_digithyphenid_continueid_startideographicids_binary_operatorids_trinary_operatorjoin_controllogical_order_exceptionlowercasemathnoncharacter_code_pointother_alphabeticother_default_ignorable_code_pointother_grapheme_extendother_id_continueother_id_startother_lowercaseother_mathother_uppercasepattern_syntaxpattern_white_spaceprepended_concatenation_markquotation_markradicalregional_indicatorsentence_terminalsoft_dottedterminal_punctuationunified_ideographuppercasevariation_selectorwhite_spacexid_continuexid_startchanges_when_casefoldedIn all cases, property names and property values may include whitespace and mixed case notation.General CategoriesAbbreviationLong FormLLetterLuUppercase LetterLlLowercase LetterLtTitlecase LetterLmModifier LetterLoOther LetterMMarkMnNon-Spacing MarkMcSpacing Combining MarkMeEnclosing MarkNNumberNdDecimal Digit NumberNlLetter NumberNoOther NumberSSymbolSmMath SymbolScCurrency SymbolSkModifier SymbolSoOther SymbolPPunctuationPcConnector PunctuationPdDash PunctuationPsOpen PunctuationPeClose PunctuationPiInitial PunctuationPfFinal PunctuationPoOther PunctuationZSeparatorZsSpace SeparatorZlLine SeparatorZpParagraph SeparatorCOtherCcControlCfFormatCsSurrogateCoPrivate UseCnUnassignedDerived CategoriesLong FormAnyAny all code points [\\u{0}-\\u{10FFFF}]AssignedAssigned all assigned characters meaning \\P{Cn}ASCIIASCII all ASCII characters [\\u{0}-\\u{7F}]Compatibility Property NamesPropertyUnicode CategoryCommentsalpha\\p{Alphabetic}Alphabetic includes more than gc = Letter. Note that combining marks (Me, Mn, Mc) are required for words of many languages. While they could be applied to non-alphabetics, their principal use is on alphabetics. Alphabetic should not be used as an approximation for word boundaries: see word below.lower\\p{Lowercase}Lowercase includes more than gc = Lowercase_Letter (Ll).upper\\p{Uppercase}Uppercase includes more than gc = Uppercase_Letter (Lu).punct\\p{gc=Punctuation} \\p{gc=Symbol} - \\p{alpha}Punctuation and symbols.digit\\p{gc=Decimal_Number}[0..9] Non-decimal numbers (like Roman numerals) are normally excluded.xdigit\\p{gc=Decimal_Number} \\p{Hex_Digit}[0-9 A-F a-f] Hex_Digit contains 0-9 A-F, fullwidth and halfwidth, upper and lowercase.alnum\\p{alpha} \\p{digit}Simple combination of other propertiesspace\\p{Whitespace}blank\\p{gc=Space_Separator} \\N{CHARACTER TABULATION}&quot;horizontal&quot; whitespace: space separators plus U+0009 tab.cntrl\\p{gc=Control}The characters in \\p{gc=Format} share some, but not all aspects of control characters. Many format characters are required in the representation of plain text.graph[^\\p{space} \\p{gc=Control} \\p{gc=Surrogate} \\p{gc=Unassigned}]Warning: the set shown here is defined by excluding space, controls, and so on with ^.print\\p{graph} \\p{blank} -- \\p{cntrl}Includes graph and space-like characters.word\\p{alpha} \\p{gc=Mark} \\p{digit} \\p{gc=Connector_Punctuation} \\p{Join_Control}This is only an approximation to Word Boundaries. The Connector Punctuation is added in for programming language identifiers, thus adding _ and similar characters.","ref":"readme.html#supported-unicode-properties","title":"Unicode Set - Supported Unicode properties","type":"extras"},{"doc":"In addition to the Unicode properties, some additional properties are also defined for convenience. These properties related to quote marks and are:quote_markquote_mark_leftquote_mark_rightquote_mark_ambidextrousquote_mark_singlequote_mark_doubleAs above these properties can be expressed in mixed case with spaces and underscores inserted for readability. They can be used in the same way as any Unicode property name.","ref":"readme.html#additional-derived-properties","title":"Unicode Set - Additional Derived properties","type":"extras"},{"doc":"Here are a few examples of sets. Although elements of the syntax appear similar to regular expressions, unicode sets only expresses one or more ranges of unicode codepoints.PatternDescription[a-z]The lower case letters a through z[abc123]The six characters a,b,c,1,2 and 3[\\p{Letter}]All characters with the Unicode General Category of LetterString ValuesIn addition to being a set of characters (of Unicode code points), a UnicodeSet may also contain string values. Conceptually, the UnicodeSet is always a set of strings, not a set of characters, although in many common use cases the strings are all of length one, which reduces to being a set of characters.This concept can be confusing when first encountered, probably because similar set constructs from other environments (regular expressions) can only contain characters.","ref":"readme.html#example-unicode-sets","title":"Unicode Set - Example Unicode Sets","type":"extras"},{"doc":"Patterns are a series of characters bounded by square brackets that contain lists of characters and Unicode property sets. Lists are a sequence of characters that may have ranges indicated by a '-' between two characters, as in &quot;a-z&quot;. The sequence specifies the range of all characters from the left to the right, in Unicode order. For example, [a c d-f m] is equivalent to [a c d e f m]. Whitespace can be freely used for clarity as [a c d-f m] means the same as [acd-fm].Unicode property sets are specified by a Unicode property, such as [:Letter:]. For a list of supported properties, see the Properties section. For details on the use of short vs. long property and property value names, see the end of this section. The syntax for specifying the property names is an extension of either POSIX or Perl syntax with the addition of =value. For example, you can match letters by using the POSIX syntax [:Letter:], or by using the Perl-style syntax \\p{Letter}. The type can be omitted for the Category and Script properties, but is required for other properties.The table below shows the two kinds of syntax: POSIX and Perl style. Also, the table shows the &quot;Negative&quot;, which is a property that excludes all characters of a given kind. For example, [:^Letter:] matches all characters that are not [:Letter:].StylePositiveNegativePOSIX-style Syntax[:type=value:][:^type=value:]Perl-style Syntax\\p{type=value}\\P{type=value}These following low-level lists or properties then can be freely combined with the normal set operations (union, inverse, difference, and intersection):ExampleMeaningA B [[:letter:] [:number:]]To union two sets A and B, simply concatenate themA &amp; B [[:letter:] &amp; [a-z]]To intersect two sets A and B, use the '&amp;' operator.A - B [[:letter:] - [a-z]]To take the set-difference of two sets A and B, use the '-' operator.[^A] [^a-z]To invert a set A, place a ^ immediately after the opening [. Note that the complement only affects code points, not string values. In any other location, the ^ does not have a special meaning.","ref":"readme.html#unicode-set-patterns","title":"Unicode Set - Unicode Set Patterns","type":"extras"},{"doc":"The binary operators of union, intersection, and set-difference have equal precedence and bind left-to-right. Thus the following are equivalent:[[:letter:] - [a-z] [:number:] &amp; [\\u0100-\\u01FF]][[[[[:letter:] - [a-z]] [:number:]] &amp; [\\u0100-\\u01FF]]Another example is that the set [[ace][bdf] - [abc][def]] is not the empty set, but instead the set [def]. That is because the syntax corresponds to the following UnicodeSet operations:start with [ace]union [bdf] -- we now have [abcdef]subtract [abc] -- we now have [def]union [def] -- no effect, we still have [def]This only really matters where there are the difference and intersection operations, as the union operation is commutative. To make sure that the - is the main operator, add brackets to group the operations as desired, such as [[ace][bdf] - [[abc][def]]].Another caveat with the &amp; and - operators is that they operate between sets. That is, they must be immediately preceded and immediately followed by a set. For example, the pattern [[:Lu:]-A] is illegal, since it is interpreted as the set [:Lu:] followed by the incomplete range -A. To specify the set of uppercase letters except for A, enclose the A in a set: [[:Lu:]-[A]].","ref":"readme.html#precedence","title":"Unicode Set - Precedence","type":"extras"},{"doc":"[a] The set containing 'a'[a-z] The set containing 'a' through 'z' and all letters in between, in Unicode order[^a-z] The set containing all characters but 'a' through 'z', that is, U+0000 through 'a'-1 and 'z'+1 through U+FFFF[[pat1][pat2]] The union of sets specified by pat1 and pat2[[pat1]&amp;[pat2]] The intersection of sets specified by pat1 and pat2[[pat1]-[pat2]] The asymmetric difference of sets specified by pat1 and pat2[:Lu:] The set of characters belonging to the given Unicode category; in this case, Unicode uppercase letters. The long form for this is [:UppercaseLetter:].[:L:] The set of characters belonging to all Unicode categories starting with 'L', that is, [[:Lu:][:Ll:][:Lt:][:Lm:][:Lo:]]. The long form for this is [:Letter:].","ref":"readme.html#examples","title":"Unicode Set - Examples","type":"extras"},{"doc":"String values are enclosed in {curly brackets}.Set expressionDescription[abc{def}]A set containing four members, the single characters a, b and c, and the string “def”[{abc}{def}]A set containing two members, the string “abc” and the string “def”.[{a}{b}{c}][abc]These two sets are equivalent. Each contains three items, the three individual characters a, b and c. A {string} containing a single character is equivalent to that same character specified in any other way.","ref":"readme.html#string-values-in-sets","title":"Unicode Set - String Values in Sets","type":"extras"},{"doc":"Single QuoteTwo single quotes represents a single quote, either inside or outside single quotes.Text within single quotes is not interpreted in any way (except for two adjacent single quotes). It is taken as literal text (special characters become non-special).These quoting conventions for ICU UnicodeSets differ from those of regular expression character set expressions. In regular expressions, single quotes have no special meaning and are treated like any other literal character.Backslash EscapesOutside of single quotes, certain backslashed characters have special meaning. Note that these are escapes processed by Unicode Set (this library) and therefore require \\\\\\\\ to be entered as a prefix. Elixir also provides similar escapes as native part of its string processing and Elixir's escapes are to be preferred where possible.EscapeDescription\\uhhhhExactly 4 hex digits; h in [0-9A-Fa-f]\\UhhhhhhhhExactly 8 hex digits\\xhh1-2 hex digitsCertain other escapes are native to Elixir and are applicable in Unicode Sets they are in any Elixir string:EscapeDescription\\aU+0007 (BELL)\\bU+0008 (BACKSPACE)\\tU+0009 (HORIZONTAL TAB)\\nU+000A (LINE FEED)\\vU+000B (VERTICAL TAB)\\fU+000C (FORM FEED)\\rU+000D (CARRIAGE RETURN)\\U+005C (BACKSLASH)\\xDDrepresents a single byte in hexadecimal (such as \\x13)\\uDDDD and \\u{D...}represents a Unicode codepoint in hexadecimal (such as \\u{1F600})Anything else following a backslash is mapped to itself, except in an environment where it is defined to have some special meaning. For example, \\p{Lu} is the set of uppercase letters in a Unicode Set.Any character formed as the result of a backslash escape loses any special meaning and is treated as a literal. In particular, note that \\u and \\U escapes create literal characters.WhitespaceWhitespace (as defined by the specification) is ignored unless it is quoted or backslashed.","ref":"readme.html#character-quoting-and-escaping-in-unicode-set-patterns","title":"Unicode Set - Character Quoting and Escaping in Unicode Set Patterns","type":"extras"},{"doc":"The following property value variants are recognized:FormatExampleDescriptionshortLuomits the type (used to prevent ambiguity and only allowed with the Category and Script properties)mediumgc=Luuses an abbreviated type and valuelongGeneral_Category=Uppercase_Letteruses a full type and valueIf the type or value is omitted, then the equals sign is also omitted. The short style is only used for Category and Script properties because these properties are very common and their omission is unambiguous.In actual practice, you can mix type names and values that are omitted, abbreviated, or full. For example, if Category=Unassigned you could use what is in the table explicitly, \\p{gc=Unassigned}, \\p{Category=Cn}, or \\p{Unassigned}.When these are processed, case and whitespace are ignored so you may use them for clarity, if desired. For example, \\p{Category = Uppercase Letter} or \\p{Category = uppercase letter}.","ref":"readme.html#property-values","title":"Unicode Set - Property Values","type":"extras"},{"doc":"To install, add the package unicode_set to your list of dependencies in mix.exs:def deps do [ {:unicode_set, &quot;~&gt; 0.11.0&quot;} ] endDocumentation can be found at https://hexdocs.pm/unicode_set.","ref":"readme.html#installation","title":"Unicode Set - Installation","type":"extras"},{"doc":"LicenseCopyright 2019 Kip ColeLicensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License athttp://www.apache.org/licenses/LICENSE-2.0Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html","title":"License","type":"extras"},{"doc":"Changelog for Unicode Set 0.11.0This is the changelog for Unicode Set 0.11.0 released on October 5th, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html","title":"Changelog for Unicode Set 0.11.0","type":"extras"},{"doc":"Fix various bugs in set operations for Union, Difference, Intersection abd ComplementCorrectly parse and interpret set complements such as [^[:^Sc:]] and more complex sets such as [^[[:Sc:]-[:^Lu:]]]Add recurively defined sets to support compatibility with Posix classes. See Unicode.Set.Property.Changelog for Unicode Set 0.10.0This is the changelog for Unicode Set 0.10.0 released on October 2nd, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#bug-fixes","title":"Changelog for Unicode Set 0.11.0 - Bug Fixes","type":"extras"},{"doc":"Fix list composition in Unicode.Set.to_uft8_char/1Changelog for Unicode Set 0.9.0This is the changelog for Unicode Set 0.9.0 released on October 2nd, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#bug-fixes","title":"Changelog for Unicode Set 0.11.0 - Bug Fixes","type":"extras"},{"doc":"Support nimble_parsec version 1.x. Thanks to @josevalim for the PR.Changelog for Unicode Set 0.8.0This is the changelog for Unicode Set 0.8.0 released on July 12th, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#enhancements","title":"Changelog for Unicode Set 0.11.0 - Enhancements","type":"extras"},{"doc":"Rewrite Unicode.Regex module to better extract character classes, process unicode sets and build Elixir regexs. Now also supports string ranges.Supports the property East Asian Width (short name ea) which is required for implementing the Unicode segmentation algorithms. Also bumps the minimum requirement for ex_unicode version 1.8.Changelog for Unicode Set 0.7.0This is the changelog for Unicode Set v.07.0 released on May 18th, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#enhancements","title":"Changelog for Unicode Set 0.11.0 - Enhancements","type":"extras"},{"doc":"Add Unicode.Set.character_class/1 which returns a string compatible with Regex.compile/2. This supports the idea of expanded Unicode Sets being used in standard Elixir/erlang regular expressions and will underpin implementation of Unicode Transforms in the package unicode_transformAdd Unicode.Regex.compile/2 to pre-process a regex to expand Unicode Sets and the compile it with Regex.compile/2. Unicode.Regex.compile!/2 is also added.","ref":"changelog.html#enhancements","title":"Changelog for Unicode Set 0.11.0 - Enhancements","type":"extras"},{"doc":"Fixes a bug whereby a Unicode Set intersection would fail with a character class that starts at the same codepoint as the Unicode set.Changelog for Unicode Set 0.6.0This is the changelog for Unicode Set v.06.0 released on May 13th, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#bug-fixes","title":"Changelog for Unicode Set 0.11.0 - Bug Fixes","type":"extras"},{"doc":"Unicode sets are now a %Unicode.Set{} structAdd Unicode.Set.Sigil implementing sigil_uAdd support for String.Chars and Inspect protocols","ref":"changelog.html#enhancements","title":"Changelog for Unicode Set 0.11.0 - Enhancements","type":"extras"},{"doc":"Fixes parsing sets to ignore non-encoded whitespaceFixes intersection and difference set operations for sets that include string ranges like {abc}Changelog for Unicode Set 0.5.1This is the changelog for Unicode Set v.05.1 released on March 14th, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#bug-fixes","title":"Changelog for Unicode Set 0.11.0 - Bug Fixes","type":"extras"},{"doc":"Compacts tuple-ranges in order to minimize the number of generated clauses in guards. Requires at least ex_unicode version 1.5.0.Changelog for Unicode Set 0.5.0This is the changelog for Unicode Set v.05.0 released on March 11th, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#bug-fixes","title":"Changelog for Unicode Set 0.11.0 - Bug Fixes","type":"extras"},{"doc":"Updates ex_unicode to version 1.4.0 which includes support for Unicode version 13.0 as well as support for several derived categories related to quote marks.Changelog for Unicode Set 0.4.2This is the changelog for Unicode Set v.04.2 released on February 25th, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#enhancements","title":"Changelog for Unicode Set 0.11.0 - Enhancements","type":"extras"},{"doc":"Allow \\n, \\t and \\r, \\s as part of character classesChangelog for Unicode Set 0.4.1This is the changelog for Unicode Set v.04.1 released on January 8th, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#bug-fixes","title":"Changelog for Unicode Set 0.11.0 - Bug Fixes","type":"extras"},{"doc":"Fix Unicode.Set.Operation.difference/2 when one list is wholly contained within anotherChangelog for Unicode Set 0.4.0This is the changelog for Unicode Set v.04.0 released on November 27th, 2019. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#bug-fixes","title":"Changelog for Unicode Set 0.11.0 - Bug Fixes","type":"extras"},{"doc":"Bump to ex_unicode to version 1.3.0 to support an expanded set of properties resolved by unicode_set.Changelog for Unicode Set 0.3.0This is the changelog for Unicode Set v.03.0 released on November 26th, 2019. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#enhancements","title":"Changelog for Unicode Set 0.11.0 - Enhancements","type":"extras"},{"doc":"Support string ranges expressed as {abc} or {abc}-{def}Note that the supported proporties in this release are script, block, category and combining class.Changelog for Unicode Set 0.2.0This is the changelog for Unicode Set v.02.0 released on November 24th, 2019. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#enhancements","title":"Changelog for Unicode Set 0.11.0 - Enhancements","type":"extras"},{"doc":"Add Unicode.Set.compile_pattern/1 and Unicode.Set.pattern/1 to generate patterns and compiled patterns compatible with String.split/3 and String.replace/3.Add Unicode.Set.utf8_char/1 that generates a list of codepoint ranges compatible with nimble_parsec combinators.Set the README for example usage.Changelog for Unicode Set 0.1.0This is the changelog for Unicode Set v.01.0 released on November 23rd, 2019. For older changelogs please consult the release tag on GitHubInitial release.","ref":"changelog.html#enhancements","title":"Changelog for Unicode Set 0.11.0 - Enhancements","type":"extras"}]